@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package RT::Extension::LocalDateHeader;
 
-our $VERSION = '0.03';
+our $VERSION = '1.00';
 
 =head1 NAME
 
@@ -21,41 +21,34 @@ syntax of mail Date: headers.
 
 =for html <p><img src="https://raw.github.com/bestpractical/rt-extension-localdateheader/master/doc/images/extension.png" alt="History Preview in Search Results" /></p>
 
-=head1 VERSION
+=head1 RT VERSION
 
-Compatible with RT 4.0 and 4.2.  Versions earlier than 4.0.8 will need to
-patch as instructed below.  Untested on 3.8.
+Compatible with RT 4.0 and 4.2.
 
-=head1 INSTALLATION 
+=head1 INSTALLATION
 
 =over
 
-=item perl Makefile.PL
+=item C<perl Makefile.PL>
 
-=item make
+=item C<make>
 
-=item make install
+=item C<make install>
 
 May need root permissions
 
-=item Edit your /opt/rt4/etc/RT_SiteConfig.pm
+=item Edit your F</opt/rt4/etc/RT_SiteConfig.pm>
 
-If you are using RT 4.2 or later, add this line:
+If you are using RT 4.2 or greater, add this line:
 
     Plugin('RT::Extension::LocalDateHeader');
 
-For earlier releases of RT 4, add this line:
+For RT 4.0, add this line:
 
     Set(@Plugins, qw(RT::Extension::LocalDateHeader));
 
 or add C<RT::Extension::LocalDateHeader> to your existing C<@Plugins> line.
 
-=item patch RT
-
-If you are running RT 4.0.7 or earlier:
-
-    patch -d /opt/rt4 -p1 < etc/callback_before_localization.diff
-
 =item Clear your mason cache
 
     rm -rf /opt/rt4/var/mason_data/obj
@@ -66,11 +59,21 @@ If you are running RT 4.0.7 or earlier:
 
 =head1 AUTHOR
 
-sunnavy <sunnavy@bestpractical.com>
+Best Practical Solutions, LLC E<lt>modules@bestpractical.comE<gt>
+
+=head1 BUGS
+
+All bugs should be reported via email to
+
+    L<bug-RT-Extension-LocalDateHeader@rt.cpan.org|mailto:bug-RT-Extension-LocalDateHeader@rt.cpan.org>
+
+or via the web at
+
+    L<rt.cpan.org|http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-LocalDateHeader>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012-2014 Best Practical Solutions, LLC.
+This software is Copyright (c) 2014 by Best Practical Solutions
 
 This is free software, licensed under:
 
